Ransaccuda Module
=================

.. automodule:: ransaccuda
   :members:
   
   .. autosummary::
      
      get_best_fitting_data_from_list_planes_cuda
      get_fitting_data_from_list_planes_cuda
      get_how_many_and_which_below_threshold_between_plane_and_points_and_their_indices_cuda
      get_how_many_below_threshold_between_line_and_points_cuda
      get_how_many_below_threshold_between_plane_and_points_cuda
      get_ransac_plane_iteration_results_cuda
      get_ransac_line_iteration_results_cuda
      get_ransac_plane_results_cuda
